#
# spec file for package termscp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           termscp
Version:        0.17.0
Release:        1.1
Summary:        Feature rich terminal UI file transfer and explorer
License:        MIT
URL:            https://github.com/veeso/termscp
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.84
BuildRequires:  cargo-packaging
BuildRequires:  zstd
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(smbclient)

# error[E0063]: missing fields `bavail`, `bfree`, `blocks` and 3 other fields in initializer of `types::stat::SmbStatVfs`
#
ExcludeArch:    i586 ppc64le s390x

%description
Termscp is a feature rich terminal file transfer and explorer, with support for
SCP/SFTP/FTP/Kube/S3/WebDAV. So basically is a terminal utility with an TUI to
connect to a remote server to retrieve and upload files and to interact with
the local file system. It is Linux, MacOS, FreeBSD, NetBSD and Windows
compatible.

%prep
%autosetup -a 1 -p 1

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%check
%{cargo_test} --features isolated-tests

%files
%{_bindir}/%{name}

%changelog
* Sun Mar 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.17.0:
  * Queuing transfers:
  - the logic of selecting files has been extended!
  - From now on selecting file will put the files into a transfer
    queue, which is shown on the bottom panel.
  - When a file is selected the file is added to the queue with a
    destination path, which is the current other explorer path at
    the moment of selection.
  - It is possible to navigate to the transfer queue by using P
    and pressing ENTER or DELETE on a file will remove it from
    the transfer queue.
  - Other commands will work as well on the transfer queue, like
    COPY, MOVE, DELETE, RENAME.
  * issue 308: added --wno-keyring flag to disable keyring
  * issue 316: Local directory path is not switching to what's
    specified in the bookmark. Now the local directory path is
    correctly set following this hierarchy:
  - Local directory path specified for the host bridge
  - Local directory path specified in the bookmark
  - Working directory
  * issue 317: the return value of --version should be 0
  * issue 319: fixed a crash when the local directory specified in
    the auth form does not exist
  * issue 327: fixed a panic when trying to go up from local
    directory on localhost in the auth form
  * issue 330: add suppaftp/pavao/kube to allowed logs
  * Dependencies:
  - argh to 0.1.13
  - bytesize to 2
  - dirs to 6
  - magic-crypt to 4
  - notify to 8
  - ssh2-config to 0.4
  - remotefs-ssh to 0.6
  - rust edition to 2024
- drop patches that were included upstream
  * 7dba691ccc001aa720d0ecf1642dda94219a2d21.patch
  * 099e2154bae9a954aab0569bf048c4d9ae71049e.patch
* Wed Nov 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.1:
  * fix: 0.16.1
  * fix: gg rust 1.82 for introducing a nice breaking change in
    config which was not mentioned in changelog
  * fix: cfg unix forbidden in rust .82
- add patches to fix build issues:
  * 099e2154bae9a954aab0569bf048c4d9ae71049e.patch
  * 7dba691ccc001aa720d0ecf1642dda94219a2d21.patch
* Tue Oct 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.0:
  * fix: tiny ui issue
  * fix: 0.16
  * feat: Show `..` directory before all the others in the explorer
    to navigate to the parent dir (#301)
  * fix: issue 292 New version alert was not displayed due to a
    semver regex issue. (#300)
  * fix: tuirealm 2.x (#299)
  * fix: users from lock
  * fix: vergen (#296)
  * fix: Use `uzers` instead of the dead package `users` which has
    several vulnerabilities (#295)
  * 285 feature request multi host (#293)
  * feat: version 0.16
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.15.0:
  * fix: include build.rs
  * fix: readme
  * fix: ci
  * fix: github ci is stable and reliable (one worker broken each 2
    weeks)
  * fix: set date
  * 280 feature request go to path auto completion (#287)
  * fix: `isolated-tests` feature to run tests for releasing on
    distributions which run in isolated environments (#286)
  * feat: it is now possible to cancel find command; show find
    progress (#284)
  * 249 feature request better search results (#282)
  * fix: popup texts
  * fix: issue 277 Fix a bug in the configuration page, which
    caused being stuck if the added SSH key was empty
  * fix: don't clear screen after terminating termscp
  * feat: Pods and container explorer for Kube protocol (#281)
  * fix: bump vers
  * fix: notify 6
  * fix: keyring test not passing macos
  * fix: bump vers
  * feat: init 0.15
  * fix: dbus deveL
  * fix: tokio rt builder
- drop patch dfe58e6147f66b4c0c74874c954e7d101b3bf026.patch
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- add patch dfe58e6147f66b4c0c74874c954e7d101b3bf026.patch to fix
  build errors due to tokio rt builder
  https://github.com/veeso/termscp/commit/dfe58e6147f66b4c0c74874c954e7d101b3bf026
* Fri Jul 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package termscp: feature rich terminal UI file transfer and
  explorer with support for SCP/SFTP/FTP/S3/SMB
